@@ -22,7 +22,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 Bob van der Poel <bob@mellowood.ca>
 
 """
-
+import json
 import os
 import time
 
@@ -270,6 +270,19 @@ def docDump():
                 print("VOICE %s" % v)
                 print("SEQ %s" % s)
 
+    elif gbl.createDocs == 5:    # JSON
+        doc = []
+        print("JSON")
+        for l in defs:
+            groove = {
+                 "groove": l[0],
+                 "description": l[2],
+                 "size": l[1],
+            }
+            [groove['track'], groove['voice'], groove['sequence']] = l[3]
+            doc.append(groove)
+        print(json.dumps(doc, indent=1))
+
     elif gbl.createDocs == 99:  # creating entry for groove browser
         for a, b in (("``", '"'), ("''", '"'), ('  ', ' ')):
             notes = notes.replace(a, b)
