@@ -146,15 +146,15 @@ def grooveDefineDo(slot):
 
 
 def grooveAlias(ln):
-    """ Create an alias name for an existing groove. """
+    """ Create an alias name for an existing groove. Note: not a copy. """
 
     global aliaslist
 
     if len(ln) != 2:
         error("DefAlias needs exactly 2 args: GrooveName AliasName.")
 
-    a = ln[0].upper()
-    g = ln[1].upper()
+    g = ln[0].upper()
+    a = ln[1].upper()
 
     if not g in glist:
         error("DefAlias: Groove %s has not been defined." % ln[0])
@@ -221,12 +221,11 @@ def groove(ln):
     if not len(tmpList):
         error("Use: Groove [selection] Name [...]")
 
-    """ If the first arg to list was an int() (ie: 3 groove1 groove2 grooveFoo)
-        we select from the list. After the selection, we reset the list to be
-        just the selected entry. This was, if there are multiple groove names
-        without a leading int() we process the list as groove list changing
-        with each bar.
-    """
+    ## If the first arg to list was an int() (ie: 3 groove1 groove2 grooveFoo)
+    ## we select from the list. After the selection, we reset the list to be
+    ## just the selected entry. This was, if there are multiple groove names
+    ## without a leading int() we process the list as groove list changing
+    ## with each bar.
 
     if wh:
         wh = (wh-1) % len(tmpList)
@@ -277,11 +276,10 @@ def grooveDo(slot):
             continue
         n.restoreGroove(slot)
 
-    """ This is important! Tracks NOT overwritten by saved grooves may
-        have the wrong sequence length. I don't see any easy way to hit
-        just the unchanged/unrestored tracks so we do them all.
-        Only done if a change in seqsize ... doesn't take long to be safe.
-    """
+    ## This is important! Tracks NOT overwritten by saved grooves may
+    ## have the wrong sequence length. I don't see any easy way to hit
+    ## just the unchanged/unrestored tracks so we do them all.
+    ## Only done if a change in seqsize ... doesn't take long to be safe.
 
     if oldSeqSize != gbl.seqSize:
         for a in gbl.tnames.values():
