@@ -25,15 +25,17 @@ This module has support for some simple default tweaks.
 """
 
 from MMA.common import *
-import MMA.pat
 import MMA.midiC
 
 import copy
 
-
 def setTweak(ln):
     """ Option tweaks. """
 
+    import MMA.pat   # here to avoid a circular dep problem
+    from miditables import drumKits
+   
+
     notopt, ln = opt2pair(ln)
 
     if notopt:
@@ -48,6 +50,19 @@ def setTweak(ln):
         elif cmd == 'DEFAULTVOICE':
             MMA.pat.defaultVoice = MMA.midiC.decodeVoice(opt)
 
+        elif cmd == 'DRUMKIT':
+            opt = opt.upper()
+            if opt.endswith('KIT'):  # optional, end kit name with 'KIT'
+                opt = opt[:-3]
+            if opt in drumKits:
+                opt = drumKits[opt]
+            else:
+                opt = stoi(opt)
+                if opt<0 or opt>127:
+                    error("Tweaks DrumKit: value must be 0..127 not '%s'." % opt)
+                    
+            MMA.pat.defaultDrum = opt
+            
         elif cmd == 'DIM':
             from MMA.chordtable import chordlist
 
@@ -59,5 +74,9 @@ def setTweak(ln):
             else:
                 error("Tweaks: DIM requires '3' or '7' arg, not '%s'." % opt)
 
+        elif cmd == 'PLECTRUMRESET':
+            import MMA.patPlectrum
+            MMA.patPlectrum.plectrumReset = getTF(opt, "Tweaks PlectrumReset")
+            
         else:
             error("Tweaks: '%s' unknown command." % cmd)
